.. _synthetic-observations:

Synthetic Observation
=====================

Methods for generating various types of synthetic observations 
from simulation data.

.. toctree::
   :maxdepth: 2

   light_cone_generator
   light_ray_generator
   planning_cosmology_simulations
   absorption_spectrum
   star_analysis
   xray_emission_fields
   sunyaev_zeldovich
   photon_simulator
   ppv_cubes
